// Lawson Labs, Inc.
// 3217 Phoenixville Pike
// Malvern, PA  19355
// 800 321-5355 or 610 725-8800
// Last modified 6-2-00
// 32-bit Windows-98/NT console application
//*********************************


#ifndef _M141_95_H
#define _M141_95_H


HINSTANCE hLib;
char timerFlag=0;
unsigned short valRead=0;


typedef struct{
ULONG		adc141;				//ADC for Model 141
double	hertzRate;			//scan rate (hz)
UINT		average;          //number of samples to average per point
UINT		ichDelay;         //interchannel delay
UINT		numData;          //number of datapoints per scan
ULONG		totScans;         //number of scans to perform
UINT		digInp;           //flag for digital input 1 = on  0 = off
UINT		biPolar;				//1 = bipolar, 0 = unipolar
BYTE 		controlCode;		//control code for next conversion in GetConv
UINT		cCode[33];        //array of control codes
ULONG		numCompleted;     //number of scans completed if scan was aborted
DWORD		calTime;			   //time in milliseconds for calibration
}	T_M141;

// function prototypes
void	SetWindowToDesktop(void);
void	DispCodes(T_M141  *M141);
void	WaitSettle(T_M141  *M141);
void	PrintCommandMenu(T_M141  *M141);
void	funcOutp(UINT outPort, int outVal);
void	SaveData(T_M141  *M141, ULONG  *dataBuffer);
void	DoCommand(T_M141  *M141, char ch, double *max, double *min);
void	StandardDev(double *stDv, double *rmsBits, double *sdTot, double *runningAvg,
			  double *sd, double *voltage, int *sdCount, int biPolar, int sdGrp);

short ADInit(ULONG adc);
short	funcInp(UINT iVal);
short	GetADC(T_M141  *M141);
short Calibrate(T_M141 *M141);
short ReadConfig(T_M141  *M141);
short WriteConfig(T_M141  *M141);
short CheckADC(UINT adc141);
short ReadStatus(T_M141 *M141, unsigned int status);
short SetupScan(T_M141  *M141, double *maxHertzRate);
short Call141(T_M141 *M141, ULONG *clientDataBuffer);

ULONG GetCount(T_M141 *M141);
UINT	GetAvg(UINT average);

double GetConv(T_M141 *M141);




//===============================================================\\
//===============================================================
//==  NEW FOR 98/NT  -  3-31-99											== 
//==  Uses Port_io.DLL and Port_io.sys Device Driver				==
//==  See special notes in m141.txt for Device Driver 			==
//==  installation and DLL usage.										==
//===============================================================
//===============================================================//

// NOTE: The following variable controls debug file output by the DLL.
// 0 = minumum output, 1 = maximum output 
BYTE bDoDebug = 0;

// Handle to DLL which communicates with port device driver "PortIO.sys"
HANDLE hLibPortio = NULL;


//\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
//======================================================================
//====  FUNCTION PROTOTYPES - both local and imported ==================
//======================================================================
/////////////////////////////////////////////////////////////////////////


// NOTE: All functions return TRUE on success and FALSE on failure.


//======================================================================
//====Pointers used to access functions exported from "PortIO.dll"======
//======================================================================
// This function MUST be called before read/write functions can be used
typedef BOOLEAN(*P_DLL_INIT)(BYTE bDoDebug);
P_DLL_INIT pDLL_Init;

// This function reads 8-bit value from port.
typedef BOOLEAN(*P_DLL_READ_PORT_UCHAR)(USHORT usPort, UCHAR* ucValRead);
P_DLL_READ_PORT_UCHAR pDLL_ReadPortUCHAR;

// This function writes 8-bit value to port.
typedef BOOLEAN(*P_DLL_WRITE_PORT_UCHAR)(USHORT usPort, UCHAR ucVal);
P_DLL_WRITE_PORT_UCHAR pDLL_WritePortUCHAR;



//======================================================================
//==== Local functions =================================================
//======================================================================
// Local functions
BOOLEAN
CheckLibFuncs(void);

BOOLEAN
LoadLibraries(void);

BOOLEAN
UnLoadLibraries(void);


BOOLEAN
WritePort(USHORT outPort, UCHAR outVal);

BOOLEAN
ReadPort(USHORT uPort, UCHAR* ucpValRead);


#endif




